/**
 * 管理数据库函数的 404 错误。
 * 如果捕获到特定的 "The requested resource wasn't found." 错误消息，则返回 null。
 * 否则，重新抛出错误。
 *
 * @template T
 * @param {() => Promise<T>} dbFunc - 要执行的数据库函数。
 * @returns {Promise<T | null>} 一个解析为数据库函数结果或 null 的 promise。
 */
export const managePb404 = async <T>(
  dbFunc: () => Promise<T>
): Promise<T | null> => {
  try {
    return await dbFunc()
  } catch (err: any) {
    if (err?.message === "The requested resource wasn't found.") {
      return null
    } else throw err
  }
}
